Skip to content

Commit 937c5ce

Browse files
issue with the implementation of column_sum_reduce (deepspeedai#804)
hi, i take a look at the code of column_sum_reduce, i have 2 questions: 1. the goal of column_sum_reduce is to get the column sum of inp matrix with shape[rows, width] and the result shape should be [width],right ? It seems that the judgment condition of pos is not suitable 2. the implementation of cuda kernel based on the asumption that, the thread with same threadIdx.y will group into a thread_block_tile, the blockDim is (32,32), i read the nvidia document https://on-demand.gputechconf.com/gtc/2017/presentation/s7622-Kyrylo-perelygin-robust-and-scalable-cuda.pdf, THREAD BLOCK TILE is a subset of threads of a thread block, divided into tiles in row-major order. doesn't it mean thread with the same threadIdx.x will group into a thread_block_tile ? thanks !!!! Co-authored-by: Reza Yazdani <44502768+RezaYazdaniAminabadi@users.noreply.github.com>
1 parent db987cf commit 937c5ce

1 file changed

Lines changed: 1 addition & 1 deletion

File tree

csrc/transformer/general_kernels.cu

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -43,7 +43,7 @@ __global__ void column_sum_reduce(const T* __restrict__ inp,
4343

4444
if (threadIdx.x == 0) {
4545
int pos = blockIdx.x * TILE_DIM + threadIdx.y;
46-
if (pos < (rows * width)) out[pos] = sum;
46+
if (pos < width) out[pos] = sum;
4747
}
4848
}
4949

0 commit comments

Comments
 (0)